package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````]18``#0```"(@0````0`!30`(``)
M`"@`&P`:``$``'#,>P``S'L``,Q[```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#8>P``V'L```4```````$`
M`0```*Q]``"L?0$`K'T!`)0"``"H$@``!@```````0`"````M'T``+1]`0"T
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DK'T`
M`*Q]`0"L?0$`5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`DGV?07C<">"@F_H=<T-`$S^>:7T$
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"$P```!-````4```
M`%0```!5````70```%X```!?````80```&(```!D````90```&8```!G````
M:@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%
MU>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[
M20``````````````````````````+!(````````#``L```````"``0``````
M`P`6`$`"`````````````!(```#A`@`````````````2````M0(`````````
M````(@```/H"`````````````!$```"G`P`````````````2`````0``````
M````````(````*8!`````````````!(```"4`@`````````````2````T@(`
M````````````$@```/@``````````````!(````6`P`````````````1````
M6P(`````````````$@```%P!`````````````!(```!'`@`````````````2
M````=```````````````$@```/,``````````````!(```!B`@``````````
M```2````)`(`````````````$@```.H!`````````````!(````$`P``````
M```````2````^P$`````````````$@````@"`````````````!(```#1````
M```````````1````3@$`````````````$@```+,``````````````!$````<
M`0`````````````2````FP(`````````````$@```(T"`````````````!$`
M``"*`0`````````````2````L@$`````````````$@```'<!````````````
M`!(```![`@`````````````2````JP$`````````````$@```(,!````````
M`````!(```#H`@`````````````2````*@$`````````````$@```!T`````
M`````````"`````=`@`````````````2````U`$`````````````$@```#("
M`````````````!(```!4```````````````2````I`(`````````````$@``
M`(,``````````````!(```"5`0`````````````2````Q`(`````````````
M$@```(\``````````````!(```!#`0`````````````2`````@(`````````
M````$@```#D"`````````````!(````)`0`````````````2````1@``````
M````````$@```/T``````````````!(```!L`0`````````````2````30(`
M````````````$@```,```````````````!(````6`@`````````````2````
MV@(`````````````$@```-P``````````````!(````K`@`````````````2
M````8P``````````````$@```/L"`````````````"$```"K`@``````````
M```2````I```````````````$@```#H!`````````````!(````L````````
M```````@````_`(`````````````$0```(,"`````````````!(```#9`0``
M```````````2````$`(`````````````$@```,X!`````````````!(```!P
M`@`````````````2````X0$`````````````$@```+H!`````````````!(`
M``#$`P``5)`!```````0`!<`L`,```$M``#H````$@`-`.@#``!1)0``Z`4`
M`!(`#0#U`@``.14``+P!```2``T`=@,``(T=```$````$@`-`(<#``!`@`$`
M`````!``%P"$!```D1T``*0!```2``T`N@0``#DK``#(`0``$@`-`'`$``!`
M@`$``````!``%P#/`P``-1\``!8````2``T`]0,``-DY``#4````$@`-``T$
M``#$.P``!````!$`#P!,!```5)`!```````0`!<`400``%20`0``````$``7
M`'P$``"M'```.````!(`#0"1!```<20``.`````2``T`HP0``.DC``!X````
M$@`-```$````@`$``````!``%@#<`P``31\``+`````2``T`O`,``$"``0``
M````$``6`$($```\@`$`!````!$`%@!F`P``J3L```(````2``T`,@0``&D[
M``!`````$@`-``8$``#U%@```````!(`#0"Q!```83D``'@````2``T``@0`
M``"``0``````(``6`)4#``!A)```$````!(`#0##`P``5)`!```````0`!<`
M'`0``.4<``"H````$@`-`&8$``"M.@``O````!(`#0!9!```_1\``.P#```2
M``T``%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`7U]E<G)N;U]L;V-A=&EO;@!R96%D`&]P96XV-`!L<V5E:S8T`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?
M<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M
M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F
M7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD
M+6QI;G5X+6%R;6AF+G-O+C,`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT
M7V5X96,`7U]B<W-?<W1A<G1?7P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?961A=&$`7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE
M`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S
M=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L
M:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?
M96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O
M9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0``````````@`"``(``@`"
M``$``P`"``(``@`$``(``0`"``$``0`"``(``@`"``(``@`!``$``0`!``(`
M`@`!``,``0`"``,``@`"``$``0`"``(``@`!``(``0`#``(``0`!``(``@`!
M``$``0`!``(``0`"``(``0`"``$``@`"``$``0`!``(``@`"``(``P`"``(`
M`P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0!2`P``$````"`````4:6D-```$`-`$
M`````````0`!`#@#```0````(````!1I:0T```,`T`0````````!``$`2`,`
M`!``````````%&EI#0```@#0!````````*Q]`0`7````L'T!`!<```#$?P$`
M%P```.A_`0`7````\'\!`!<````$@`$`%P````R``0`7````$(`!`!<````8
M@`$`%P```!R``0`7````((`!`!<````D@`$`%P```"B``0`7````,(`!`!<`
M```T@`$`%P```#R``0`7````R'\!`!4%``#,?P$`%0@``-!_`0`5#0``U'\!
M`!4/``#8?P$`%1D``-Q_`0`5&P``X'\!`!4>``#D?P$`%2<``.Q_`0`5-```
M]'\!`!4^``#X?P$`%4,``/Q_`0`51```T'X!`!8#``#4?@$`%@0``-A^`0`6
M!0``W'X!`!8'``#@?@$`%@D``.1^`0`6"@``Z'X!`!8+``#L?@$`%@P``/!^
M`0`6#@``]'X!`!80``#X?@$`%A$``/Q^`0`6$@```'\!`!83```$?P$`%A0`
M``A_`0`6%0``#'\!`!86```0?P$`%A<``!1_`0`6&```&'\!`!8:```<?P$`
M%AP``"!_`0`6'0``)'\!`!8?```H?P$`%B```"Q_`0`6(0``,'\!`!8B```T
M?P$`%B,``#A_`0`6)```/'\!`!8E``!`?P$`%B8``$1_`0`6)P``2'\!`!8H
M``!,?P$`%BD``%!_`0`6*@``5'\!`!8K``!8?P$`%BP``%Q_`0`6+0``8'\!
M`!8N``!D?P$`%B\``&A_`0`6,```;'\!`!8Q``!P?P$`%C(``'1_`0`6,P``
M>'\!`!8U``!\?P$`%C8``(!_`0`6-P``A'\!`!8X``"(?P$`%CD``(Q_`0`6
M.@``D'\!`!8[``"4?P$`%CP``)A_`0`6/0``G'\!`!9```"@?P$`%D$``*1_
M`0`60@``J'\!`!9%``"L?P$`%D8``+!_`0`61P``M'\!`!9(``"X?P$`%DD`
M`+Q_`0`62@``P'\!`!9+```(0"WI00$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E
M?&P!``#&C^(6RHSB?/R\Y0#&C^(6RHSB=/R\Y0#&C^(6RHSB;/R\Y0#&C^(6
MRHSB9/R\Y0#&C^(6RHSB7/R\Y0#&C^(6RHSB5/R\Y0#&C^(6RHSB3/R\Y7A'
M_><`QH_B%LJ,XD#\O.4`QH_B%LJ,XCC\O.4`QH_B%LJ,XC#\O.4`QH_B%LJ,
MXBC\O.4`QH_B%LJ,XB#\O.4`QH_B%LJ,XAC\O.5X1_WG`,:/XA;*C.(,_+SE
M`,:/XA;*C.($_+SE>$?]YP#&C^(6RHSB^/N\Y0#&C^(6RHSB\/N\Y0#&C^(6
MRHSBZ/N\Y0#&C^(6RHSBX/N\Y0#&C^(6RHSBV/N\Y0#&C^(6RHSBT/N\Y0#&
MC^(6RHSBR/N\Y0#&C^(6RHSBP/N\Y0#&C^(6RHSBN/N\Y0#&C^(6RHSBL/N\
MY0#&C^(6RHSBJ/N\Y0#&C^(6RHSBH/N\Y0#&C^(6RHSBF/N\Y0#&C^(6RHSB
MD/N\Y0#&C^(6RHSBB/N\Y0#&C^(6RHSB@/N\Y0#&C^(6RHSB>/N\Y0#&C^(6
MRHSB</N\Y0#&C^(6RHSB:/N\Y0#&C^(6RHSB8/N\Y0#&C^(6RHSB6/N\Y0#&
MC^(6RHSB4/N\Y0#&C^(6RHSB2/N\Y0#&C^(6RHSB0/N\Y7A'_><`QH_B%LJ,
MXC3[O.4`QH_B%LJ,XBS[O.4`QH_B%LJ,XB3[O.4`QH_B%LJ,XAS[O.4`QH_B
M%LJ,XA3[O.4`QH_B%LJ,X@S[O.4`QH_B%LJ,X@3[O.4`QH_B%LJ,XOSZO.4`
MQH_B%LJ,XO3ZO.4`QH_B%LJ,XNSZO.4`QH_B%LJ,XN3ZO.4`QH_B%LJ,XMSZ
MO.4`QH_B%LJ,XM3ZO.4`QH_B%LJ,XLSZO.4`QH_B%LJ,XL3ZO.4`QH_B%LJ,
MXKSZO.4`QH_B%LJ,XK3ZO.4`QH_B%LJ,XJSZO.4`QH_B%LJ,XJ3ZO.4`QH_B
M%LJ,XISZO.4`QH_B%LJ,XI3ZO.4`QH_B%LJ,XHSZO.5PM5M-B+!;2WU$6TS-
MZ000!:@#D@2I`ZI\1.M8&V@'DT_P``/_]T+O5$I52Z)8X%@11@+P'_M32^-8
M'7@`+6O044OD6"!H__?6[P-&(&B3^,8C0O`"`H/XQB/_]\SO!9V0^,8S*AT#
M-4/P`0.R\8!/@/C&,W/2D`#_]]SN0TH$G`-&>D1"27E$4&`B:!I@04H%F'I$
MVF!`2@$H"6AZ1)E@6F!>W2$=!.N`#@/Q#`Q1^`1+3/@$3W%%^=$#,#=.`"$`
MD2I&?D1#^"`0-4GP:'E$__<P[P1&>+,R30:N?43H:/_WBNXP2#%&>$0`\._X
M0+,N2WM$V&C_]U+N__<0[RQ*'$MZ1--8&F@'FUI`3_```RG1($8(L'"]__>`
M[B5*>D308!"S__<T[A=+Y%@@:/_W8N^`^'U7A>?P:/_W,N\$1LKGJ&@0L0'P
M/_O1YQI(,49X1`#PN_BH8``HR=#SY__W".\$(*KG__<N[@$@__>2[H!I`0`,
M`0``<&D!`"@!```P`0``&`$``!0!``"&:@$`>FH!`)(I``"$*0``1&H!`#L&
M```L:@$`^"8``!9J`0"&:`$`ZFD!`"PF``!/\``+3_``#@*\:D8$M`&TW_@D
MH`BCFD3?^"#`6O@,P$WX!,T&2UKX`S`&2%KX``#_]SKN__?H[IAG`0```0``
M)`$``"P!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$6___J>&<!`"`!```&
M2`=+!TIX1'M$>D2#0@/0!4O36`.Q&$=P1P"_UF@!`-1H`0!69P$`"`$```A(
M"4MX1`E*>T0;&GI$V0\!ZZ,!21`#T`5+TU@#L1A'<$<`OZQH`0"H:`$`*&<!
M`#0!```(M0I+"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_W1.W_][__!DL!(GM$
M&G`(O79H`0#X9@$`!`$``"IH`0!6:`$`Q.<`ORWI^$.!1A]+>T0`*#;0'DJ;
M6-/X`("X\0`/,=`%>`]&`"T8OSTM%+\!)0`E$]'8^`!`;+%&1B!&*D9)1O_W
M5NX0N6-=/2L0T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&EZPD%X>>F
MZP@&`34L1+80/F`@1KWH^(,$1N?G1$;EY[1F`0`X`0``.$HY2WI$+>GP09ZP
MTU@;:!V33_```Q"Q`W@$1F.Y,THQ2WI$TU@::!V;6D!/\``#5M$>L+WH\('_
M]U;M!48`*.W0*T]_1"A&__?R[0`H-M##?`#Q$P8N*P+1<W@`*_+0PWPN*S+0
M($;_]V[M@$8P1O_W:NU`1`(P__="[3M&3_#_,@$A`98&1@"4__=\[0*J,48#
M(/_WWNT!,#!&!=`&FP/T<$.S]8!/%]#_]^[L,$;_][#L*$;_][SM`"C(T2A&
M__?F[2!&__>R[*CG<W@N*\G1LW@`*[;0Q>?_]Y'_YN?_]\3L+&8!``P!```.
M9@$`@",``-_X9,`92_Q$$+4$1IRP`R!<^`,P:D8A1AMH&Y-/\``#__>V[:"Y
M!)L#]'!#L_4@3QB_L_6`3PW0#4H,2WI$TU@::!N;6D!/\``#"]$<L!"]`"#Q
MYP(A($;_]U[ML/J`\$`)Z>?_]XCL-F4!``P!````90$`+>GP0PY&+$DL2ZWU
M@%UY1(.P!$8-]8!0!##?^*2`RU@!KT#V_W(Y1AMH`V!/\``#)$CX1'A$__>,
M[+#Q``P;W0*M#/'_.4U$%?@$/(.[N?$`#Q'02D8O(3A&__<>[5BQ&4M8^`,P
M&&C_]V3M2T8Z1B%&__<P[0G@$TM8^`,P&&C_]UCM,D8A1O_W7.P/2@WU@%$*
M2P0Q>D336!IH"VA:0$_P``,&T0WU@%T#L+WH\(/A1L_G__<F[+ID`0`,`0``
MEF0!`#`B```4`0``,F0!`%A*64MZ1"WI\$<,1H*P!4;36-_X6($;:`&33_``
M`PMX^$0]*PB_`30@1O_W<NQI1@9&*$;_]X+^@48`*%30__=H[(9"1]E*2P"?
M6/@#@+\`*W@`*QB_/2L4OP$C`",'T"M&$_@!+P`J&+\]*OG16QNP'-CX`&`8
M1/_W)NSP4>BQV/@`,"A&V5D0^`$["W``*QB_/2L)T$H<$/@!.Q%&`O@!.STK
M&+\`*_;1"D8](PMP%/@!.P+X`3\`*_G1+4HJ2WI$TU@::`&;6D!/\``#1M$"
ML+WH\(<)\?\Y%/@!.PGX`3\`*_G1Z><A2UCX`X#8^`!P.VB#LSM&4_@$+TE&
M"?$!"0`J^-$#,8D`&TIZ1!-HN[D(1@$C$V#_]];K@D8`*,S0.49/ZHD'.D;_
M]U#KR/@`H,WX`)`)\0$)`"-*^"DPAN<X1O_WBNN"1LCX````*+303^J)!^SG
MF48((=7G__=JZP"_]&,!``P!``#88P$`.`$``#AC`0!L9`$`,+413!%+@[!\
M1.58*&C_]VSL*&C_]VCL#4H.2PY)>T2B6'E$__?BZRAH__=>[`M+"TH`)`M)
M>T1Z1,WI`#1Y1/_W_NL#L#"]=&(!`!0!```0`0``IEX```8@``#:(@``N0X`
M``8@```0M0A,"$M\1.-8&&C_]SCL!DH'2P=)>T2B6'E$O>@00/_WKKL.8@$`
M%`$``!`!``!&7@``IA\``"1*,+4D2WI$K?4`78FP#?4`406LTU@<,1MH"V!/
M\``#__=<ZQU)0?(!`AU+>43-Z0`!>T0!(2!&__=ZZPWU@%$8,2!&3_2`4@.1
M__<,ZP0>N+\`)0K;8!S_]RCK!48HL0.9(D;_][+J`",K50U*#?4`40E+'#%Z
M1--8&F@+:%I`3_```P31*$8-]0!=";`PO?_WPNK680$`#`$``)P?``"*'P``
M9F$!`/_WJK];2BWI\$\&1EI+>D2M]81=@[!92`WUA%0-\1@(TU@-1GA$048$
M-!MH(V!/\``#__<A_2\A!$8P1O_W$NO`L4](,49X1/_W>/XP1DU*#?6$44A+
M!#%Z1--8&F@+:%I`3_```T#P@H`-]81=`["]Z/"/,$;_]^KJ0TF!1BA&>43_
M]U+K`"C;T$!+!T;?^`"A>T0%DS]+^D1[1`23.W@`*S_0++$Y1B!&__<0Z@`H
M0M`X1O_WRNI"'KL8NEPO*@;1`"4=<`$X$_@!+2\J^=`)\0$#`T2S]8!?LMHN
M2B&M`2%31GI$*$;-Z0$F3_2`4@"7__?*ZD)&*48#(/_W+.LHN0J;`_1P0[/U
M`$\=T"-)`"!Y1/_W".L'1@`OD=`[>``KO]$$LR-X+BL"T`6?`2#.YV-X`"OY
MT1E)`"!Y1/_W].H'1@`OZM%[YP$A*$;_]^#J`"C;T1-(*49X1/_W[OTH1O_W
M`.IRYP2?`2"PY__W`.H`OR9A`0`,`0``!!\``.X>``#<8`$`Q!X``)(>``"P
M'@``BAX``&P>```R'@``"!X``-H=```#>#NQ0APO*PB_$$82^`$[`"OXT7!'
M`+\0M:BS`W@$1I.S__=`ZD,>(T2<0C+2&D8"X!-&HD(MT!-&$O@!&2\I]]"<
M0B;2`3N<0B70&G@O*OG1`3L#X!%X`3LO*0+1&D:<0OC3$AN3'+/U@%^(OP`@
M"=@12"%&3_2`4P$R>$0$1O_WE.D@1A"]#$B]Z!!`>$3_]Y*YG$+<T2-X+RL%
MT`A(O>@00'A$__>'N09(O>@00'A$__>!N0"_H&`!`.X<```$'0``S!P``-U*
MW_AXP]Y+>D1PM?Q$#/$,#(RPVT[36`WQ"`Y^1`&L&V@+DT_P``/73;SH#P"N
MZ`\`?42\Z`\`KN@/`-SX`#"N^``P(48P1O_WWONPL<]+`9CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?(^P`HZ-'$3GY$(48P1O_WP/NP
ML<!+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>J^P`H
MZ-&V3GY$(48P1O_WHONPL;%+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__>,^P`HZ-&H3GY$(48P1O_WA/NPL:)+`9CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=N^P`HZ-&:3GY$(48P1O_W9ONP
ML9-+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=0^P`H
MZ-&,3GY$(48P1O_W2/NPL81+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__<R^P`HZ-%^3GY$(48P1O_W*ONPL75+`9CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<4^P`HZ-%P3GY$(48P1O_W#/NP
ML69+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?V^@`H
MZ-%B3GY$(48P1O_W[OJPL5=+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__?8^@`HZ-%43GY$(48P1O_WT/JPL4A+`9CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>Z^@`HZ-%&3GY$(48P1O_WLOJP
ML3E+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__><^@`H
MZ-$X2"%&>$3_]Y7Z`488L39(>$3_]_'[-4@A1GA$__>*^@%&&+$R2'A$__?F
M^S%((49X1/_W?_H!1JBQ+TAX1/_WV_LN22Y(>41X1/_WU?LM2A9+>D336!IH
M"YM:0$_P``,=T0RP<+TH2"%&>$3_]V+Z`48@L25(>$3_][[[X><D20HB#?$9
M`'E$__?*Z``HV-$@2`WQ(P%X1/_WKOO1Y_[WQN\`O[Q>`0``6P``#`$``,@<
M``"27@$`.`$``'(<```^'```#AP``-H;``"N&P``#AL``$(;```2&P``XAH`
M`"H:``!T&@``4!H``'(:``!Z&@``?!H``*@9``"6&@``\!D``)Y;`0!2&@``
MWAD``$H:``"^&0``%TL821A*>T1Y1`"U&&B#L(I80QP2:`&23_```@S0$TH1
M2WI$TU@::`&;6D!/\``#$]$#L%WX!/L-2&E&>$3_]^WY,+$`>#`H&+\`*!2_
M`2``(`A+>T088.'G_O=<[P"_%EP!`-!:`0`,`0``MEH!```9``#(6P$`"+7^
M]Q+O_O<$[P"Q`&@(O2Y*+TMZ1/"U+DZ'L`5&TUA^1`2I,$8;:`633_```__W
MN?D0L0-X!$:+N2=*)$MZ1--8&F@%FUI`3_```SS1(T@I1GA$!["]Z/!`__<%
MNRE&_O?$[EBQ'DH92WI$TU@::`6;6D!/\``#)M$'L/"]*$;^]WKO!T8@1O[W
M=N\X1`(P_O=.[Q-+%$H!(7M$`I1Z1`"5`9)/\/\R!$;^]X3O#TH'2WI$TU@:
M:`6;6D!/\``#!+\A1C!&Q=#^]^CN3%H!``P!```P&0``(EH!`/X8``#V60$`
MVA<``-(7``"N60$`+>GP3]_X3!6M]0%-W_A(18&PW_A(I7Q$0*\B':?Q=`,'
MD`WU`$7?^#@%!/$0#/PU*#1X1*?Q:`ZG\>`&^D1!6`EH*6!/\``!I_%<!0?*
M@^@'`+SH#P`/Q9SH`P"%Z`,`E.@'`([H!P#?^/@$,49X1/_W(/D@L0-X!$8`
M*T#P8('^]UKN_O=,[@`H`/!Q@05H`"T`\)>!*$;^]_;N0``!,/[WSNXJ>(!&
M@K'?^+RT1$;[1"!&`));1D_P_S(!(0(T_O<`[Q7X`2\`*O+1W_B<!*?Q6`5X
M1`+@5?@$"XBQ,4;_]^CX!$8`*/;0`W@`*_/0__>@^0`H[]`@1O[W4NX$1M"Y
M3_``":?Q=`L'ZXD"4OAT3(2Q"?$!!0OKA04B>%*Q($8)\0$)__>%^0`H7-%5
M^`1+`"SRT0`D($;^]Z;N@T9`1O[WHNZ#1`OR!$M81O[W>.[?^!PT3_#_,@$A
M>T0"D]_X$#3-^`R`@$9[1`&3W_@(-`"4>T3^]Z;N3_3@<4!&_O>T[@$P!='^
M]Y;N`6@1*4#PQH`R1D%&`R#^]Q3O!49(L_9)!YOV2EKX`0!/\``*&VAZ1,WX
M`(`!(0!H_O>T[O!*#?4`0>-+_#%Z1--8&F@+:%I`3_```T#PNH%01@WU`4T!
ML+WH\(\@1O[WVNT$1@`HBM"@YU?XT#P#]'!#L_6`3\[15_C(3/[WENV$0LC1
M5_C0/,/S"`.S]>!_P=%81O[W#NZ"1MA(,49X1/_W0O@`*`#PR8`'FQQH_O>R
M[0%&($;_]_WZ@T8`*`#PO8!81O[W&NX$1@,H#]G,200X6$1Y1/[W4NU`N00L
M`/`N@5Q$%/@%/"\K`/`H@<5,?$0C:%H<`/"E@``K`/"W@,%)PDAY1-_X")-X
M1,%/__=M^<%._O?F[<!+3_#_,@$A>T0#D[Y+^43-^`"`?T1[1,WI`3"[2U!&
M?D1[1/[W_.T4X/[W].T#:!$K%]'^]\KM`36$1DM&(D8!(5!&S>D#5\WI`6S-
M^`"`_O?F[4_TX'%01O[W]NT$1D,<XM!`1O[W).VI2%%&>$3_]S#Y4$;_]P'^
M3^>62@>;6O@"`$_P``H;:*)*S>D`@0$A>D0`:/[W]NT_Y__W[OV=2H-+#?4`
M07I$_#'36!IH"VA:0$_P``-`\/B`($8-]0%-`;"]Z/!/_O<6O8!&I_%H!`?K
MB`-3^&@,R+$(\0$+!.N+!03@5?@$"XBQ"_$!"S%&V$;^]XS_`"CTT`-X`"OQ
MT/[W_.P%1@`H?_1RKN#G@DT-(/[W0NU3(H!&?41RYJA&U.<'F]/X`+`^YWQ(
M,49X1/[W;?\`*`#PBH`#>``K&+\P*Q6_`2,`(P$C(V`8OR-@?_1)KUA&`"'^
M]QKM!$8`*#_T0:]/\/\S;_`1`@(F/1\`EO[W^NP&(BE&($;^]X3L%_@$/!NY
M%_@#/$,K8=``(P`B`),@1@`C_O?H[`#PY?\&1@/@*48P1@'P&_A/]`!"*48@
M1O[W:.P"'O/<W_ADL2!&I_$P"?[WI.VG\44%,4;[1$Q&I_$Q!J?Q1``!\&OX
M%?@!+R!&`));1D_P_S(!(?[W%NT"-*Y"\M%*2@$AS?@(D%!&>D1(2\WI`((`
M(@?X""Q[1$9*>D0#DD_P_S+^]_[L'N<'FUQH`"P_]-.N($;^]]CL`RA_]LVN
M/4D$."!$>43^]P[L`"@(OZ-&PN8@8(#G%_@"/$$KF=$7^`$\0RN5T3MX2"N2
MT7MX12N/T4_P_S-O\#D"($8`EO[W=NPI1BDB($;^]P#L*TLK24_P_S)[1,WI
M`E,I2WE$4$;-Z0"!>T0!(?[WO.S;YO[W+.P,`0``GEH!`#19`0`^60$`]A8`
M`,@7``!,%P``,!<``"(6```,%P``'`$``!X7``"F5P$`^A8``,P6```X6`$`
MS!4``#X5``"J%@``3!<``,@4``!8%P``TA0``(86``!2%```7A4``"16`0"P
M%````!0```(4``#B$@``A!0``$@5``!.%```SA0``$X2``#V$P``7TA@27A$
M\+5?2X.P7TI!6'M$;D8):`&13_```9Q8(&C^]^CL!48@:/[WY.PQ1I7X:#"`
M^&DP5DAX1/[W1_X0L0-X,2MZT/_W/?H@:/[WTNQ020,C`2)Y1/[W"NP%1FBQ
M(&C^]\CL*VE+2AEH>D3^]\KK*VD;:)MH6P)NU"!H_O>Z[$9)`R,!(GE$_O?R
MZP5&>+%#2#%&>$3^]QC^!T8@:``O3]#^]Z;L*VDZ1AEH_O>JZR!H_O>>[`5&
M(&C^]YKL.$D!(GE$_O?^ZS=*`48H1GI$-DW^]Y;K(&C^]XSL`T9]1#-(`"(Q
M1GA$@_AI(/[W[?T$1JA@L+%/].!Q($;^]P+L0AP#1A$H&+\!*B_8*4H<2WI$
MTU@::`&;6D!/\``#(]$#L/"]:&C_]W;\!$:H8``HX=$@2'A$_O?6ZT-X`"N#
MT(#G_O=6[!Q+*FE[1!!H6V@9:/[WM/ZKYR!H_O=*["MI&6C^]^#KB.?^]RSK
M%$DB1A1(>41X1$EH"6C^][3KA%,!``P!``!X4P$`%`$``)@1```R$P``(!,`
M``P3``#R$```U!(``.`2```H5`$`E!```'92`0""$@``O%,!`)13`0!F$@``
M,DHS2WI$\+4'1H.PTU@;:`&33_```__W&?D#>`1&.[%"'"\K"+\41A+X`3L`
M*_C1*$X]'AB_`25^1#-H6APLT``K#+\`)07P`05=N2)*($MZ1--8&F@!FUI`
M3_```S+1`[#PO3MX`"OPT!Q)!"(@1GE$_O>^ZP`HZ-$92A1+>D336!IH`9M:
M0$_P``,;T3A&`["]Z/!`_O=[O1)(:49X1/[W,/UHL0-X`"L8OS`K"K\`(P$C
M,V#)T`$C,V``+<70T.<P8,+G_O>:Z@"_O%$!``P!``#,4@$`<%$!`&P0``!"
M40$`A@\``"WI\$\`\4`!W_A@2]_X8#NM]2-]?$3N1G)&`/&`#``GXU@;:*&3
M3_```U'I`F178-=@$#(VND+X$&PC"B4"`_1_0P@Q0^H48P7T?P5#Z@1C845#
MZ@4#0O@(/.;1K?$(!@[U_'<`(X1&-$96^`@/U.D&A2)OU/A(H&%OU/A,D(+J
M"@)T:(+J"`*!Z@D!0D!I0,;XA#!A0)08T@^^0D+J00)"Z@0"QOB`(-[18$;>
M^`!0W.D#)H1HW.D`>4_JE`@"F4CJ@GA']ID2Q?:"(DCJA'@$:JT83^K7;-WX
M$.!,ZDD<+1F$:4SJ1QP<ZP4%W?APH(;J!`R$:`SJ!`R$:8SJ!`P5ZPP%ANH(
M#(D8#.H'#`D9C.H&#!'K#`P>ZP(!3^J7#HD93NJ)?MWX&)!.ZH=T#.OU;(CJ
M!`X.Z@4.3^JU!8[J"`X1ZPX.&>L"`1'K"`&$Z@4(W?@@D`CJ#`B(Z@0(#NO\
M;A'K"`A/ZKP,&>L"`=WX*)`)&87J#`0$Z@X$".O^:&Q`3^J^#@P9&>L"`4D9
MC.H.!=WX,)`%Z@@%A>H,!03K^&1-&4_JN`@9ZP(!W?@XD!'K#`&.Z@@,#.H$
M#`7K]&6,Z@X,3^JT!!'K#`P9ZP(!$>L.`8CJ!`[=^$"0#NH%#H[J"`X,Z_5L
M$>L.#D_JM049ZP(!W?A(D!'K"`&$Z@4(".H,"`[K_&Z(Z@0(3^J\#!'K"`@9
MZP(!"1F%Z@P$W?A0D`3J#@1L0`CK_F@,&4_JO@X9ZP(!W?A8D$D9C.H.!07J
M"`4$Z_ADA>H,!4_JN`A-&1GK`@$1ZPP!CNH(#-WX8)`,Z@0,C.H.#`7K]&41
MZPP,3^JT!!GK`@'=^&B0$>L.`8CJ!`X.Z@4.#.OU;([J"`Y/ZK4%$>L.#AGK
M`@$1ZP@!A.H%"`CJ#`@.Z_QNB.H$"$_JO`P1ZP@(&NL"`0D9A>H,!`CK_FD$
MZ@X$W?AX@&Q`3^J^#@D9&.L"!-WX@(!D&8SJ#@4%Z@D%`>OY887J#`5/ZKD)
M9!D8ZP(%%>L,!8[J"0S=^(B`#.H!#(SJ#@P$Z_%D%>L,#$_JL0$8ZP(%W?B0
MH!7K#@6)Z@$.#NH$#@SK]&R.Z@D.3^JT!!7K#@4:ZP(.'NL)#H'J!`D%Z_QH
M">H,"2:=B>H!"4_JO`P>ZPD.JAC=^*"@4AB$Z@P!`>H(`0[K^&YA0$_JN`51
M&$[VH3+&]MEBW?BH@!KK`@H!Z_YA&NL$!(SJ!0J*Z@X*3^J^#A3K"@3=^+"0
M&.L""(7J#@H$Z_%DBNH!"ACK#`Q/ZK$!W?BX@!SK"@P9ZP()CNH!"@SK]&R*
MZ@0*&>L%!4_JM`05ZPH%W?C`D!CK`@B!Z@0*!>O\98KJ#`H8ZPX.3^J\#![K
M"@[=^,B`A.H,"AGK`@F*Z@4*&>L!"0[K]6$9ZPH)3^JU!1CK`@K=^-#@&NL$
M"@GK\62,Z@4)B>H!"4_JL0$:ZPD*'NL""=WXV(`9ZPP)"NOT;(7J`0J*Z@0*
M3^JT!!GK"@D8ZP(*W?C@X!KK!0H)Z_QE@>H$"8GJ#`E/ZKP,&NL)"A[K`@G=
M^.B`&>L!"0KK]6&$Z@P*BNH%"D_JM049ZPH)&.L""-WX\.`8ZP0(">OQ9(SJ
M!0F)Z@$)3^JQ`1CK"0@>ZP(.W?CXH![K#`Z%Z@$,".OT:(SJ!`Q/ZK0$W?@`
MD1[K#`X:ZP(,@>H$"@[K^&Z*Z@@*'.L%#$_JN`@<ZPH,0IV$Z@@*&>L""0SK
M_FR*Z@X*&>L!"4_JO@X9ZPH)1)FM&(CJ#@J*Z@P*+!D)Z_QE3^J\#!3K"@3=
M^!B1CNH,"HD8!.OU9(KJ!0H1ZP@!3^JU!1'K"@&,Z@4*&>L""0'K]&&*Z@0*
MW?@@@1GK#@E/ZK0+&>L*"=WX*.$)Z_%D&.L""(7J"PD8ZPP(B>H!"4_JL0$8
MZPD)W?@PP1[K`@J+Z@$.CNH$#AKK!0H)Z_1E3^JT!!KK#@J!Z@0(W?@XX1SK
M`@R(Z@4('.L+#`KK]6H<ZP@,3^JU!1[K`@)2&(3J!0'=^$#A@>H*`4_JN@A1
M&$OVW$+(]AMR#.OZ;![K`@Y%Z@@*W?A(D1[K!`0*Z@P*!>H(#@'K_&%*Z@X*
M3^J\#!3K"@X9ZP($9!E(Z@P%".H,"MWX4)$-0`[K\6Y%Z@H%3^JQ`2T9&>L"
M"4SJ`009ZP@*#.H!"]WX6)$$Z@X$!>O^943J"P1/ZKX.%.L*!!GK`@D9ZPP)
M0>H.#`'J#@K=^&"!#.H%#`3K]61,Z@H,3^JU!1SK"0P8ZP((&.L!`0SK]&A.
MZ@4,#NH%"MWX:)$,Z@0,3.H*#$_JM`0<ZP$,&>L""47J!`$9ZPX*!>H$"]WX
M<)$!Z@@!#.OX;$'J"P%/ZK@.$>L*`1GK`@D9ZP4*`>O\943J#@%/ZKP)W?AX
M@0'J#`$$Z@X,0>H,`1'K"@P8ZP(!"1E.Z@D$#NH)"MWX@($L0`SK]6Q$Z@H$
M3^JU!6082>H%"ACK`@@$Z_QD&.L."&*93^J\#@KJ#`H)Z@4,2NH,"AKK"`R)
M&!'K"0A%Z@X)!>H."F29">H$"0SK]&Q)Z@H)3^JT!!GK"`B)&$D93NH$!0[J
M!`D%Z@P%1>H)!0CK_&AM&&:93^J\#`7K^&6)&$3J#`D$Z@P*$>L.#@GJ"`EH
MF4GJ"@E/ZK@(&>L."8D8$>L$#@GK]61,Z@@)#.H("FJ9">H%"4GJ"@E/ZK4%
M&>L.#HD8$>L,`4CJ!0P(Z@4)#.H$#$SJ"0P.Z_1N'.L!#&R93^JT!`SK_FR)
M&$7J!`D%Z@0*$>L("`GJ#@ENF4GJ"@E/ZKX.&>L("8D8$>L%"`GK_&5$Z@X)
M!.H."G"9">H,"4GJ"@E/ZKP,&>L("4[J#`B)&`CJ!0@)&0GK]60.Z@P)3^JU
M!4CJ"0A,Z@4)&.L!"'*9#.H%"@GJ!`F)&`CK]&@1ZPX.=)E/ZK0$2>H*"1GK
M#@F)&$7J!`X)Z_AI$>L,"@[J"`Y/ZK@,=ID%Z@0(0V!.Z@@.!.H,"![K"@Z*
M&%(91.H,!07J"05XF47J"`4.Z_ENK1A,\M82S/9B(D_JN0D1ZP((>ID8ZP0(
MC.H)!(3J#@0%Z_YE&.L$"$_JO@Z)&(GJ#@01ZPP,?)EL0`CK]6@<ZP0,3^JU
M!8D8CNH%!!'K"0E^F0SK^&R$Z@@$&>L$"4_JN`B,&("9%.L.!`GK_&Z%Z@@)
MPV")Z@P)3^J\#!3K"001ZP()&>L%"8*9B.H,!03K_F2%Z@X%3^J^#AGK!0F-
M&!7K"`6$F0GK]&B,Z@X)B>H$"4_JM`05ZPD%$>L""1GK#`F&F8[J!`P%Z_AE
MC.H(#$-A&>L,"4_JN`P1ZP((B)D8ZPX(">OU;H3J#`G#88GJ!0E/ZK4%&.L)
M"!'K`@D9ZP0)BID(Z_YDC.H%"(CJ#@A/ZKX.&>L("1'K`@@8ZPP(C)D)Z_1L
MA>H."8GJ!`E/ZK0$&.L)"!'K`@D9ZP4)CID(Z_QECNH$"(CJ#`A/ZKP,&>L(
M"1'K`@@8ZPX(D)D)Z_5NA.H,"8GJ!0E/ZK4%&.L)"!'K`@D9ZP0)DID(Z_YD
MC.H%"(CJ#@A/ZKX.&>L("1'K`@@8ZPP(E)D)Z_1LA>H."8GJ!`E/ZK0$&.L)
M"!'K`@D9ZP4)EID(Z_QECNH$"(CJ#`A/ZKP,&>L("1'K`@@8ZPX(F)D)Z_5N
MA.H,"8GJ!0E/ZK4%&.L)"(D8$>L$"0CK_F2:F8SJ!0B(Z@X(3^J^#AGK"`F)
M&!'K#`@)Z_1LA>H."9R9B>H$"4_JM`08ZPD)B1@)Z_QI31F>F0;KN08&88[J
M!`:&Z@P&3^J\#*T9BAC2&83J#`&!Z@D!$NL.`@7K^652&(%H`NOU8FD8A6D"
M8`)J'.L%!8%@I!@+2L#I"$,)2WI$A6'36!IHH9M:0$_P``,#T0WU(WV]Z/"/
M_??6[`"_Q%`!``P!``",10$`"+6`(/WW%.V?[0][`"*"9X#M`'N?[0Y[@.T"
M>Y_M#GN`[01[G^T.>X#M!GN?[0Y[@.T(>Y_M#GN`[0I[@.T,>PB]`+^O\P"`
M`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````````
M````+>GX0P5&%D:`:@`C#$;W%]7I#"$`Z\8,A$7H:G/K```"T@$R0?$``:AO
M!?$X",7I"L-S#T/JQP.;&"MC0>M7<6EC@+L_+D/=IO%`"4_JF19W'`3KAQ<A
M1D-&!/%`#M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#^`0L
MZ]$,1BA&__?!^;Q"X=&IZX86,D8Y1D!&_?<<[*YGO>CX@\#Q0`<A1K="0$2H
MOS=&.D;]]Q#LJV\[1*MG0"ONT2A&]AL\1/_WH?FYYR=&X.<MZ?!!`?$X!PQ&
MBVH%1@YK@"&3^H/XP_/%`S:Z6ARX&#@J^51$W<+Q0`(`(?WWMNP@1O_W@_DX
M1C@B`"']]Z[L($;$Z1QH__=Y^>-X*W`@1F.(:W`C:!L*JW`C:.MPXWHK<6.)
M:W&C:!L*JW&C:.MQXWPK<F.*:W(C:1L*JW(C:>MRXWXK<V.+:W.C:1L*JW.C
M:>MSE/@C,"MT8XQK="-J&PJK="-JZW2]Z/!!_?>BN\+Q.`(`(?WW<NS!YRWI
M^$,'1@Q.#$V(1GY$D49]1/WW6.MV&[80"M`$/0`D5?@$/TI&048X1@$TF$>F
M0O;1O>CX@P"_.$(!`#!"`0!P1P"_`DM[1!MH_?>INP"_4D0!``A`+>D(@+WH
M`0`"`#L````^````"P```#X````0````/@```"4````^````,P```#X````#
M````/@````8````^````%````#X````.````/@````T````^````)````#X`
M```2````/@```"<````^`````@```#X````8````/@````D````^````"@``
M`#X``````````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O
M<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10``
M```Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]0
M5`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%
M0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0``
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````
M<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S
M8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`
M````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N
M,#4R````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`
M````5$5-4$1)4@!435``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&
M2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2![
M"B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C
M:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@
M96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H
M:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L
M(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R
M971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H
M*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I
M('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S
M92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A
M<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*
M;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M
M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D
M:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M````.P```#X````+````/@```!`````^````)0```#X````S````/@````,`
M```^````!@```#X````4````/@````X````^````#0```#X````D````/@``
M`!(````^````)P```#X````"````/@```!@````^````"0```#X````*````
M/@``````````````*)O_?P$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````1@`
M`,$7```!````*`,```$````X`P```0```$@#```!````4@,```P````L$@``
M#0```+P[```9````K'T!`!L````$````&@```+!]`0`<````!````/7^_V^T
M`0``!0```%0)```&````I`(```H```#:!```"P```!`````5``````````,`
M``#$?@$``@```.@!```4````$0```!<```!$$```$0```&0/```2````X```
M`!,````(````'@````@```#[__]O`0``"/[__V\$#P``____;P,```#P__]O
M+@X``/K__V\0````````````````````````````````````````````````
M`````````+1]`0```````````#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(`
M`#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``
M.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X
M$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2``"I.P``````
M``````````````````````````````````````!I.P```````#D5````````
M````````````````!(`!`/____^$/P``M#P```````!T/0``>#T``'@_``"\
M/```@#\```````!D/P``;#\```````",/P``1T-#.B`H1&5B:6%N(#$Q+C(N
M,"TQ,"D@,3$N,BXP`$$R````865A8FD``2@````%-RU!``8*!T$(`0D""@02
M!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`
M+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG
M;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````
M```````````````````````````````````````````````+`````0````(`
M``!4`0``5`$``!D```````````````$`````````$P````<````"````<`$`
M`'`!```D```````````````$`````````"8````'`````@```)0!``"4`0``
M(```````````````!``````````T````]O__;P(```"T`0``M`$``/`````%
M``````````0````$````/@````L````"````I`(``*0"``"P!@``!@````,`
M```$````$````$8````#`````@```%0)``!4"0``V@0``````````````0``
M``````!.````____;P(````N#@``+@X``-8````%``````````(````"````
M6P```/[__V\"````!`\```0/``!@````!@````,````$`````````&H````)
M`````@```&0/``!D#P``X`````4`````````!`````@```!S````"0```$(`
M``!$$```1!```.@!```%````%0````0````(````?`````$````&````+!(`
M`"P2```,```````````````$`````````'<````!````!@```#@2```X$@``
M``,`````````````!`````0```""`````0````8````X%0``.!4``(0F````
M``````````@`````````B`````$````&````O#L``+P[```(````````````
M```$`````````(X````!`````@```,0[``#$.P``"$``````````````!```
M``````"6`````0``<((```#,>P``S'L```@````-``````````0`````````
MH0````$````"````U'L``-1[```$```````````````$`````````*L````.
M`````P```*Q]`0"L?0``!```````````````!`````0```"W````#P````,`
M``"P?0$`L'T```0```````````````0````$````PP````8````#````M'T!
M`+1]```0`0``!@`````````$````"````,P````!`````P```,1^`0#$?@``
M/`$`````````````!`````0```#1`````0````,`````@`$``(```$``````
M``````````0`````````UP````@````#````0(`!`$"````4$```````````
M```$`````````-P````!````,`````````!`@```'P```````````````0``
M``$```#E`````P``<```````````7X```#,```````````````$`````````
H`0````,``````````````)*```#U```````````````!````````````
